pub fn send_after<A, M, R>(
actor_ref: &R,
msg: M,
delay: Duration,
) -> JoinHandle<()>Expand description
Schedule a single message to be sent after delay.
Returns a JoinHandle that completes once the message has been sent
(or the delay has elapsed and the actor is no longer reachable).